searchData={"items":[{"type":"module","title":"FStrings","doc":"`FStrings` module that provides the `~f\"...\"` sigil to be able to do F-strings-like interpolation.\n\nCheck [this](README.md) for an intro and instructions on how to use it.","ref":"FStrings.html"},{"type":"macro","title":"FStrings.sigil_f/2","doc":"~f sigil for f-strings.","ref":"FStrings.html#sigil_f/2"},{"type":"macro","title":"Examples - FStrings.sigil_f/2","doc":"iex> import FStrings\n    iex> abc=3\n    iex> ~f\"The value 🎉 #{abc}=\"\n    \"The value 🎉 'abc'='3'\"\n    iex> sigil_f(\"hello world #{abc}= #{abc}\", [])\n    \"hello world 'abc'='3' 3\"","ref":"FStrings.html#sigil_f/2-examples"},{"type":"module","title":"FStrings.Logger","doc":"Simple Logger wrapper to help using the FStrings library for logs.\n\nUse it like this:\n\n```elixir\n  iex> use FStrings.Logger\n  iex> abc = 42\n  iex> Logger.info(~f\"This is the meaning of life #{abc}=\")\n  # Will log an info message: \"This is the meaning of life 'abc'='42'\"\n```","ref":"FStrings.Logger.html"},{"type":"macro","title":"FStrings.Logger.error/2","doc":"A wrapper around `Logger.error/2` to be able to use the F-string interpolation without having to specify the `~f\"...\"` sigil.\n\nAccepts the exact same arguments. Check `Logger.error/2` docs for more info.","ref":"FStrings.Logger.html#error/2"},{"type":"macro","title":"FStrings.Logger.info/2","doc":"A wrapper around `Logger.info/2` to be able to use the F-string interpolation without having to specify the `~f\"...\"` sigil.\n\nAccepts the exact same arguments. Check `Logger.info/2` docs for more info.","ref":"FStrings.Logger.html#info/2"},{"type":"macro","title":"FStrings.Logger.warning/2","doc":"A wrapper around `Logger.warning/2` to be able to use the F-string interpolation without having to specify the `~f\"...\"` sigil.\n\nAccepts the exact same arguments. Check `Logger.warning/2` docs for more info.","ref":"FStrings.Logger.html#warning/2"},{"type":"extras","title":"F-Strings","doc":"# F-Strings\n\n[![Build Status](https://github.com/amalbuquerque/elixir-fstrings/actions/workflows/elixir.yml/badge.svg)](https://github.com/amalbuquerque/elixir-fstrings/actions/workflows/elixir.yml) [![Hex.pm](https://img.shields.io/hexpm/v/f_strings.svg)](https://hex.pm/packages/f_strings) [![Documentation](https://img.shields.io/badge/documentation-blue)](https://hexdocs.pm/f_strings)","ref":"readme.html"},{"type":"extras","title":"Intro 🔭 - F-Strings","doc":"A library that aims to provide some of the features that [Python F-strings have](https://docs.python.org/3/tutorial/inputoutput.html#formatted-string-literals).\n\nIt currently allows the usage of the `=` specifier after the interpolation, meaning that it will\nexpand the interpolated expression to the text of the expression, an equal sign, then\nthe representation of the evaluated expression. Both the text and the evaluated expression\nare wrapped in single quotes.\n\n```elixir\niex(1)> import FStrings\nFStrings\n\niex(2)> world = \"Jupiter\"\n\"Jupiter\"\n\niex(3)> ~f\"Hello, #{world}=\"\n\"Hello, 'world'='Jupiter'\"\n\niex(4)> ~f\"Hello, #{world}\"\n# no trailing `=` means regular interpolation\n\"Hello, Jupiter\"\n```\n\nIf you really want to have an `=` immediately after the interpolation, use double equals (ie. `==`) to get a single equals:\n\n```elixir\niex(5)> ~f\"Hello, #{world}==biggest!\"\n# trailing `==` means regular interpolation, with an equals symbol immediately after it.\n\"Hello, Jupiter=biggest!\"\n```","ref":"readme.html#intro"},{"type":"extras","title":"Use it with Logger - F-Strings","doc":"This kind of interpolation where we want the actual expression to be present in the string is usually needed for logging. To help with that, you can use the `FStrings.Logger` module that will allow you to use the F-string interpolation without having to specify the `~f\"...\"` sigil 😎\n\n\n```elixir\nuse FStrings.Logger\n\nfoo = 42\n\nLogger.info(\"Important value #{foo}=\")\n# Important value 'foo'='42'\n```\n\nThe last statement will log `Important value 'foo'='42'`; note the F-string interpolation without having to specify the `~f` sigil.","ref":"readme.html#use-it-with-logger"},{"type":"extras","title":"Installation 💾 - F-Strings","doc":"The package can be installed by adding `f_strings` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:f_strings, \"~> 0.1.0\"}\n  ]\nend\n```\n\nIt will be fetched from [hex.pm](https://hex.pm): https://hex.pm/packages/f_strings","ref":"readme.html#installation"},{"type":"extras","title":"Changelog 📆 - F-Strings","doc":"### **v0.1.0 (2025-07-24)**\n- First version\n    * Ready to be used, always wraps F-string interpolation in quotes\n    * Provides `FStrings.Logger` to facilitate interpolation of `Logger` messages","ref":"readme.html#changelog"},{"type":"extras","title":"Next steps 🚧 - F-Strings","doc":"1. `[ ]` Allow modifiers to be passed to the sigil to control the wrapping character:\n  - 'x' for no wrapping,\n  - 'q' for quotes,\n  - 'p' for parentheses,\n  - 's' for square brackets,\n  - 'c' for curly brackets\n\n2. `[ ]` Allow `wrap_in` option to be passed to `use FStrings.Logger` for the default wrapping character\n\n3. `[ ]` Allow `x|q|p|s|c` to be passed before `=` to set different wrapping character for single interpolation","ref":"readme.html#next-steps"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}